@@ -22,10 +22,12 @@
  * USA
  */
 
+#include "gchempaint-config.h"
 #include "mesomer.h"
 #include "mesomery.h"
 #include "molecule.h"
 #include "document.h"
+#include <glib/gi18n-lib.h>
 
 TypeId MesomerType;
 
@@ -56,7 +58,7 @@ gcpMesomer::gcpMesomer (gcpMesomery* mesomery, gcpMolecule* molecule) throw (std
 {
 	if (!mesomery || !molecule)
 		throw invalid_argument ("NULL argument to gcpMesomer constructor!");
-	SetId (const_cast<char*> ("ms1"));
+	SetId ((char*) "ms1");
 	mesomery->AddChild (this);
 	GetDocument ()->EmptyTranslationTable();
 	AddChild (molecule);
