@@ -4,7 +4,7 @@
  * GChemPaint library
  * settings.cc 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,9 +24,11 @@
 
 #include "gchempaint-config.h"
 #include "settings.h"
-gchar *Color = "black";
-gchar *DeleteColor = "red";
-gchar *AddColor = "green";
-gchar *SelectColor = "cyan";
+gchar *Color = (char*) "black";
+gchar *DeleteColor = (char*) "red";
+gchar *AddColor = (char*) "green";
+gchar *SelectColor = (char*) "cyan";
 unsigned MaxStackSize = 0;//infinite size authorized for undo:redo stacks
 bool MergeAtoms = true;
+int CompressionLevel = 0;
+bool TearableMendeleiev = false;
