@@ -177,7 +177,7 @@ static int set_fontsize (double val) {return (int) (val * PANGO_SCALE);}
 
 gcpThemeManager::gcpThemeManager ()
 {
-	bindtextdomain(GETTEXT_PACKAGE, DATADIR"/locale");
+	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
 #ifdef ENABLE_NLS
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
@@ -243,7 +243,7 @@ gcpThemeManager::~gcpThemeManager ()
 	map <string, gcpTheme*>::iterator i, iend = m_Themes.end ();
 	for (i = m_Themes.begin (); i != iend; i++) {
 		theme = (*i).second;
-		if (def && theme == def)
+		if (!theme || (def && theme == def))
 			continue; // this theme has already been deleted
 		if (theme->modified && theme->m_ThemeType == LOCAL_THEME_TYPE) {
 			xmlDocPtr doc = xmlNewDoc((xmlChar*)"1.0");
@@ -513,9 +513,15 @@ void gcpThemeManager::AddFileTheme (gcpTheme *theme, char const *label)
 
 void gcpThemeManager::RemoveFileTheme (gcpTheme *theme)
 {
-	char const *name = theme->GetName ().c_str ();
-	m_Themes.erase (name);
+	char const *name = NULL;
+	map <string, gcpTheme*>::iterator i, iend = m_Themes.end ();
+	for (i = m_Themes.begin (); i != iend; i++)
+		if ((*i).second == theme) {
+			name = (*i).first.c_str ();
+			break;
+		}
 	m_Names.remove (name);
+	m_Themes.erase (name);
 }
 
 void gcpThemeManager::ChangeThemeName (gcpTheme *theme, char const *name)
@@ -980,8 +986,7 @@ void gcpTheme::RemoveClient (Object *client)
 	set <Object*>::iterator iter = m_Clients.find (client);
 	if (iter != m_Clients.end ())
 		m_Clients.erase (iter);
-	if (m_ThemeType == FILE_THEME_TYPE && m_Clients.size () == 0)
-	{
+	if (m_ThemeType == FILE_THEME_TYPE && m_Clients.size () == 0) {
 		ThemeManager.RemoveFileTheme (this);
 		delete this;
 	}
