@@ -22,6 +22,7 @@
  * USA
  */
 
+#include "gchempaint-config.h"
 #include "retrosynthesisarrow.h"
 #include "retrosynthesis.h"
 #include "retrosynthesisstep.h"
@@ -32,13 +33,13 @@
 #include "lib/widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-bpath.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
+#include <cmath>
 
 TypeId RetrosynthesisArrowType = NoType;
 
 gcpRetrosynthesisArrow::gcpRetrosynthesisArrow(gcpRetrosynthesis *rs): gcpArrow (RetrosynthesisArrowType)
 {
-	SetId ("rsa1");
+	SetId ((char*) "rsa1");
 	if (rs)
 		rs->AddChild( this);
 	m_Start = m_End = NULL;
