@@ -41,13 +41,13 @@ gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 	xmlNodePtr node;
 	const char *name;
 	char *path;
-	GDir* dir = g_dir_open (DATADIR"/gchempaint/templates", 0, NULL);
+	GDir* dir = g_dir_open (PKGDATADIR"/templates", 0, NULL);
 	xmlIndentTreeOutput = true;
 	xmlKeepBlanksDefault (0);
 	if (dir) {
 		while ((name = g_dir_read_name (dir))) {
 			if (strcmp (name + strlen (name) - 4, ".xml")) continue;
-			name = g_strconcat (DATADIR"/gchempaint/templates/", name, NULL);
+			name = g_strconcat (PKGDATADIR"/templates/", name, NULL);
 			doc = xmlParseFile (name);
 			docs.insert (doc);
 			node = doc->children;
